# coding: utf-8

from __future__ import absolute_import

from flask import json
from six import BytesIO

from fabric_cf.orchestrator.swagger_server.models.resources import Resources  # noqa: E501
from fabric_cf.orchestrator.swagger_server.models.status400_bad_request import Status400BadRequest  # noqa: E501
from fabric_cf.orchestrator.swagger_server.models.status401_unauthorized import Status401Unauthorized  # noqa: E501
from fabric_cf.orchestrator.swagger_server.models.status403_forbidden import Status403Forbidden  # noqa: E501
from fabric_cf.orchestrator.swagger_server.models.status404_not_found import Status404NotFound  # noqa: E501
from fabric_cf.orchestrator.swagger_server.models.status500_internal_server_error import Status500InternalServerError  # noqa: E501
from fabric_cf.orchestrator.swagger_server.test import BaseTestCase


class TestResourcesController(BaseTestCase):
    """ResourcesController integration test stubs"""

    def test_portalresources_get(self):
        """Test case for portalresources_get

        Retrieve a listing and description of available resources for portal
        """
        query_string = [('graph_format', 'GRAPHML'),
                        ('level', 1),
                        ('force_refresh', false),
                        ('start_date', 'start_date_example'),
                        ('end_date', 'end_date_example'),
                        ('includes', 'includes_example'),
                        ('excludes', 'excludes_example')]
        response = self.client.open(
            '//portalresources',
            method='GET',
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))

    def test_resources_get(self):
        """Test case for resources_get

        Retrieve a listing and description of available resources. By default, a cached available resource information is returned. User can force to request the current available resources.
        """
        query_string = [('level', 1),
                        ('force_refresh', false),
                        ('start_date', 'start_date_example'),
                        ('end_date', 'end_date_example'),
                        ('includes', 'includes_example'),
                        ('excludes', 'excludes_example')]
        response = self.client.open(
            '//resources',
            method='GET',
            query_string=query_string)
        self.assert200(response,
                       'Response body is : ' + response.data.decode('utf-8'))


if __name__ == '__main__':
    import unittest
    unittest.main()



#!/usr/bin/env python3
# MIT License
#
# Copyright (c) 2020 FABRIC Testbed
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#
# Author: Komal Thareja (kthare10@renci.org)
from __future__ import annotations

from abc import abstractmethod
from typing import TYPE_CHECKING

from fabric_cf.actor.core.apis.abc_callback_proxy import ABCCallbackProxy
from fabric_cf.actor.core.apis.abc_server_reservation import ABCServerReservation
if TYPE_CHECKING:
    from fabric_cf.actor.core.kernel.resource_set import ResourceSet


class ABCAuthorityReservation(ABCServerReservation):
    """
    IAuthorityReservation defines the reservation interface for authorities(AM) processing requests for resources.
    """
    @abstractmethod
    def get_deficit(self):
        """
        Returns the number of concrete units this reservation is short or in excess of.
        @returns number of concrete units this reservation is short or in excess of
        """

    @abstractmethod
    def get_ticket(self) -> ResourceSet:
        """
        Returns the ticket backing the reservation.
        @returns ticket
        """

    @abstractmethod
    def set_send_with_deficit(self, *, value: bool):
        """
        Sets the "send with deficit" flag.
        @params value : true, reservations with no pending operations but with a
                 deficit will be sent back without attempting to fix the deficit,
                false - if a deficit exists, the system will attempt to fix it.
        """

    @abstractmethod
    def set_broker_callback(self, *, broker_callback: ABCCallbackProxy):
        """
        Set the Broker Callback Proxy
        @param broker_callback Broker callback
        """

    @abstractmethod
    def get_broker_callback(self) -> ABCCallbackProxy:
        """
        Get the Broker Callback Proxy
        """

    @abstractmethod
    def prepare_extend_lease(self):
        """
        Prepare for an incoming extend request on this existing
        reservation. Note: unlocked

        @throws Exception thrown if request is rejected (e.g., ticket not valid)
        """

    @abstractmethod
    def prepare_modify_lease(self):
        """
        Prepare for an incoming modify request on this existing
        reservation. Note: unlocked

        @throws Exception thrown if request is rejected (e.g., ticket not valid)
        """
